# 需求管理

## 数据结构

### 1.字典需求表（dt_demand）

| 字段          | 字段说明       | 数据类型    | 备注                                         |
| ------------- | -------------- | ----------- | -------------------------------------------- |
| id            | 主键            | varchar(40) | 32位UUID                                     |
| code          | 编码            | varchar(40) | 全局唯一，6位流水号                             |
| user_name     | 用户名          | varchar(200)|                                              |
| dept_name     | 部门名称         | varchar(200)|                                              |
| product_line  | 产线            | tinyint(4)  | 1:业务 2：研发 3：实施                          |
| subject       | 主题            | varchar(1024)|                                              |
| content       | 内容            | varchar(1024)|                                              |
| bill_state    | 需求状态         | tinyint(4)  | 0:待提交 1:待回复 2:已接受 3:已拒绝 4:待完善 5:论证中 |
| respondent    | 回复人          | varchar(200) |                                              |
| reply         | 回复内容         | varchar(1024)|                                              |
| submit_time   | 提交时间         | char(14)    | 格式为yyyyMMddHHmmss                          |
| estimate_time | 预计回复日期      | char(8)     | 格式为yyyyMMdd                                |
| answer_time   | 回复时间         | char(14)    | 格式为yyyyMMddHHmmss                          |
| creator       | 创建人账号id     | varchar(32)  |                                              |
| creation_time | 创建时间         | char(14)    | 格式为yyyyMMddHHmmss                          |
| modified_time | 最后更新时间      | char(14)    | 格式为yyyyMMddHHmmss                          |
| modifier      | 最后更新账号id    | varchar(32) |                                              |
| valid         | 合法标识         | tinyint(4)  | 0-无效,1-有效                                  |
| ts            | 乐观锁           | timestamp   |                                              |

## DDL语句

### 字典需求表

```sql
CREATE TABLE IF NOT EXISTS `dt_demand`  (
  `id` varchar(40) NOT NULL COMMENT '主键',
  `code` varchar(40) NULL DEFAULT NULL COMMENT '编码-全局唯一',
  `user_name` varchar(200) NOT NULL COMMENT '用户名',
  `dept_name` varchar(200) NOT NULL COMMENT '部门名称',
  `product_line` tinyint NOT NULL COMMENT '产线 - 1:业务 2：研发 3：实施',
  `subject` varchar(1024) NULL DEFAULT NULL COMMENT '主题',
  `content` varchar(1024) NULL DEFAULT NULL COMMENT '内容',
  `bill_state` tinyint NOT NULL DEFAULT 0 COMMENT '需求状态 - 0:待提交 1:待回复 2:已接受 3:已拒绝 4:待完善 5:论证中',
  `respondent` varchar(200) NULL DEFAULT NULL COMMENT '回复人',
  `reply` varchar(1024) NULL DEFAULT NULL COMMENT '回复内容',
  `submit_time` char(14) NULL DEFAULT NULL COMMENT '提交时间',
  `estimate_time` char(8) NULL DEFAULT NULL COMMENT '预计回复日期',
  `answer_time` char(14) NULL DEFAULT NULL COMMENT '回复时间',
  `creator` varchar(32) NULL DEFAULT NULL COMMENT '创建人',
  `creation_time` char(14) NULL DEFAULT NULL COMMENT '创建时间',
  `modifier` varchar(32) NULL DEFAULT NULL COMMENT '最后修改人',
  `modified_time` char(14) NULL DEFAULT NULL COMMENT '最后修改时间',
  `valid` tinyint NULL DEFAULT NULL COMMENT '合法标识',
  `ts` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '乐观锁',
  PRIMARY KEY (`id`) USING BTREE,
  INDEX `idx_state`(`bill_state`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COMMENT = '字典需求' ROW_FORMAT = Dynamic;
```